@@ -1,5 +1,6 @@
 from hachoir_metadata.metadata import RootMetadata, registerExtractor
 from hachoir_metadata.safe import fault_tolerant
+from hachoir_parser.container import SwfFile
 from hachoir_parser.misc import TorrentFile, TrueTypeFontFile, OLE2_File, PcfFile
 from hachoir_core.field import isString
 from hachoir_core.error import warning
@@ -18,20 +19,26 @@ class TorrentMetadata(RootMetadata):
 
     def extract(self, torrent):
         for field in torrent[0]:
-            if field.name in self.KEY_TO_ATTR:
-                key = self.KEY_TO_ATTR[field.name]
-                value = field.value
-                setattr(self, key, value)
-            elif field.name == "info" and "value" in field:
-                self.processInfo(field["value"])
-    def processInfo(self, info):
-        for field in info:
-            if field.name in self.INFO_TO_ATTR:
-                key = self.INFO_TO_ATTR[field.name]
-                value = field.value
-                setattr(self, key, value)
-            elif field.name == "piece_length":
-                self.comment = "Piece length: %s" % field.display
+            self.processRoot(field)
+
+    @fault_tolerant
+    def processRoot(self, field):
+        if field.name in self.KEY_TO_ATTR:
+            key = self.KEY_TO_ATTR[field.name]
+            value = field.value
+            setattr(self, key, value)
+        elif field.name == "info" and "value" in field:
+            for field in field["value"]:
+                self.processInfo(field)
+
+    @fault_tolerant
+    def processInfo(self, field):
+        if field.name in self.INFO_TO_ATTR:
+            key = self.INFO_TO_ATTR[field.name]
+            value = field.value
+            setattr(self, key, value)
+        elif field.name == "piece_length":
+            self.comment = "Piece length: %s" % field.display
 
 class TTF_Metadata(RootMetadata):
     NAMEID_TO_ATTR = {
@@ -165,8 +172,17 @@ class PcfMetadata(RootMetadata):
             key = self.PROP_TO_KEY[name]
             setattr(self, key, value)
 
+class SwfMetadata(RootMetadata):
+    def extract(self, swf):
+        self.height = swf["rect/ymax"].value # twips
+        self.width = swf["rect/xmax"].value # twips
+        self.format_version = "flash version %s" % swf["version"].value
+        self.frame_rate = swf["frame_rate"].value
+        self.comment = "Frame count: %s" % swf["frame_count"].value
+
 registerExtractor(TorrentFile, TorrentMetadata)
 registerExtractor(TrueTypeFontFile, TTF_Metadata)
 registerExtractor(OLE2_File, OLE2_Metadata)
 registerExtractor(PcfFile, PcfMetadata)
+registerExtractor(SwfFile, SwfMetadata)
 
