@@ -340,6 +340,22 @@ def checkAngelBear(meta): return (
     checkAttr(meta, 'frame_rate', 4.0),
 )
 
+def checkHotelCalifornia(meta): return (
+    checkAttr(meta, 'title', u"Hotel California"),
+    checkAttr(meta, 'artist', u"The Eagles"),
+    checkAttr(meta, 'duration', timedelta(seconds=51, microseconds=512834)),
+    checkAttr(meta, 'nb_channel', 2),
+    checkAttr(meta, 'sample_rate', 44100),
+    checkAttr(meta, 'bits_per_sample', 16),
+    checkAttr(meta, 'producer', u'reference libFLAC 1.1.2 20050205'),
+)
+
+def checkRadpoor(meta): return (
+    checkAttr(meta, 'title', u"\u062a\u0633\u062a"),
+    checkAttr(meta, 'author', u'Soroosh Radpoor'),
+    checkAttr(meta, 'creation_date', datetime(2008, 9, 2, 16, 8, 30)),
+)
+
 def checkFile(filename, check_metadata, quality=1.0):
     sys.stdout.write("  - Create parser: ")
     sys.stdout.flush()
@@ -447,6 +463,8 @@ testcase_files = (
     (u"pentax_320x240.mov", checkPentax320),
     (u"gps.jpg", checkGPS),
     (u"angle-bear-48x48.ani", checkAngelBear),
+    (u"hotel_california.flac", checkHotelCalifornia),
+    (u"radpoor.doc", checkRadpoor),
 )
 
 if __name__ == "__main__":
